import requests


def buscar_avatar(usuario):
    url = f'http://api.github.com/users/{usuario}'
    resp = requests.get(url)
    return resp.json()['avatar_url']


if __name__ == "__main__":
    print(buscar_avatar('joaonetoeng'))
